#!/usr/bin/perl
use strict;
use warnings;

use File::Copy;

use FindBin;
use lib $FindBin::RealBin;

use DevTools qw/get_version/;
use Archive::Zip;
use Archive::Zip::Tree;

#------------------------------------------------------------------------------
# determine version and version date:
#------------------------------------------------------------------------------
my ($version, $datum) = get_version("$FindBin::RealBin/../spip/spip.pl");
#print "Version: $version vom $datum\n";exit;
my $dir = "spip_$version";


#------------------------------------------------------------------------------
# delete versionised directory:
#------------------------------------------------------------------------------
if (-d $dir) {
    unless (eval { qx(rm -r $dir 2>&1) } ) {
        print "$dir deleted (via rm -r).\n";
    }
    else {
        unless (eval { qx(rmdir /S /Q $dir 2>&1) } ) {
            print "$dir deleted (via rmdir /S /Q).\n";
        }
    }
}

#------------------------------------------------------------------------------
# create directories:
#------------------------------------------------------------------------------
mkdir $dir;
mkdir "$dir/spip";
mkdir "$dir/spip/templates";
mkdir "$dir/spip/documentation";
mkdir "$dir/spip/documentation/sheets";
mkdir "$dir/spip/documentation/pictures";
mkdir "$dir/spip/documentation/html";
mkdir "$dir/spip/documentation/source";
mkdir "$dir/devtools";

#------------------------------------------------------------------------------
# copy spip.pl:
#------------------------------------------------------------------------------
copy("$FindBin::RealBin/../spip/spip.pl", "$dir/spip");

#------------------------------------------------------------------------------
# copy templates:
#------------------------------------------------------------------------------
for my $file (<$FindBin::RealBin/../spip/templates/*>) {
    #print "File $file\n";
    copy($file, "$dir/spip/templates");
}

#------------------------------------------------------------------------------
# copy documentation:
#------------------------------------------------------------------------------
for my $file (<$FindBin::RealBin/../spip/documentation/*>) {
    copy($file, "$dir/spip/documentation") unless -d $file;
}
for my $subdir (qw/sheets pictures html source/) {
    for my $file (<$FindBin::RealBin/../spip/documentation/$subdir/*>) {
        copy($file, "$dir/spip/documentation/$subdir");
    }
}

#------------------------------------------------------------------------------
# copy development tools:
#------------------------------------------------------------------------------
for my $file (<$FindBin::RealBin/../devtools/*>) {
    #print "File $file\n";
    copy($file, "$dir/devtools");
}

print "$dir created.\n";




#------------------------------------------------------------------------------
# zip the created directory:
#------------------------------------------------------------------------------
my $zip = new Archive::Zip;
$zip->addTree($dir, $dir);
$zip->writeToFileNamed("$dir.zip");

print "$dir.zip created.\n";
